import axios from 'axios';
import store from '@/store';
import { ElMessage } from 'element-plus';
import { isCheckTimeout } from '@/utils/auth';

const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  timeout: 100000
});

// 1.请求拦截器
service.interceptors.request.use(
  (config) => {
    // 请求接口之前 做些什么
    //1.统一注入token
    if (store.getters.token) {
      if (isCheckTimeout()) {
        //超时 执行退出
        store.dispatch('user/logout');
        return Promise.reject(new Error('token 失效'));
      }
      if (!config.url.startsWith("/jcApi")) {
        config.headers.Authorization = `${store.getters.token}`;
      }

    }
    //2.设置headers icode
    // config.headers.code = '';
    // 必须返回 config
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// 2.响应拦截器
service.interceptors.response.use(
  // 请求成功的处理
  (response) => {
    const { success, code, msg, message, data  } = response.data;
    // 需要判断当前请求是否成功
    if (success && code === 10000) {
      return data; // 成功后返回解析后的数据
    } else if (code === 200 || code == "00000" || code == "10000" || msg == 'success') {
      return data; // 成功后返回解析后的数据
    } else if (code === 401) {
      store.dispatch('user/logout');
      ElMessage.error(message); // 提示错误信息
      ElMessage({ message: message || msg, grouping: true, type: 'error' })
    } else {
      // 失败（请求成功 ，业务失败） 弹出消息提示
      ElMessage({ message: message || msg, grouping: true,  type: 'error' })
      return Promise.reject(new Error(message));
    }
  },
  // 请求失败处理
  (error) => {
    //token过期
    if (
      error.response &&
      error.response.data &&
      error.response.data.code === 401
    ) {
      store.dispatch('user/logout');
    }
    // ElMessage({
    //   message: error.message,
    //   grouping: true,
    //   type: 'error'
    // })
    // return Promise.reject(error);
  }
);

export default service;
